/**
 * Maintains the history of an object
 */
"use strict";

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var History = (function () {
    function History() {
        var undoLimit = arguments.length <= 0 || arguments[0] === undefined ? 10 : arguments[0];

        _classCallCheck(this, History);

        this.undoLimit = undoLimit;
        this.undoList = [];
        this.redoList = [];
    }

    /**
     * Get the limit of undo/redo actions
     *
     * @returns {number|*} the undo limit, as it is configured when constructing the history instance
     */

    _createClass(History, [{
        key: "getUndoLimit",
        value: function getUndoLimit() {
            return this.undoLimit;
        }
    }, {
        key: "last",
        value: function last() {
            return this.undoList[this.undoList.length - 1];
        }

        /**
         * Keep an object to history
         * @param obj
         */
    }, {
        key: "keep",
        value: function keep(obj) {
            this.undoList.push(obj);
            this.redoList = [];
            if (this.undoList.length > this.undoLimit) {
                this.undoList.shift();
            }
        }

        /**
         * Undo the last object
         *
         * @returns {Object} the object before the last keep
         */
    }, {
        key: "undo",
        value: function undo() {
            if (this.undoList.length > 0) {
                // keep the latest to the redoList
                this.redoList.push(this.undoList.pop());
                if (this.redoList.length > this.undoLimit) {
                    this.redoList.shift();
                }
            }
            // deliver the last one but do not remove it
            return this.undoList.length > 0 ? this.undoList[this.undoList.length - 1] : null;
        }

        /**
         * Redo the last object, redo happens only if no keep operations have been performed
         *
         * @returns {null}
         */
    }, {
        key: "redo",
        value: function redo() {
            if (this.redoList.length > 0) {
                this.undoList.push(this.redoList.pop());
                return this.undoList.length > 0 ? this.undoList[this.undoList.length - 1] : null;
            }
            return null;
        }

        /**
         * Checks whether we can perform a redo operation
         *
         * @returns {boolean}
         */
    }, {
        key: "canRedo",
        value: function canRedo() {
            return this.redoList.length > 0;
        }

        /**
         * Checks whether we can perform an undo operation
         *
         * @returns {boolean}
         */
    }, {
        key: "canUndo",
        value: function canUndo() {
            return this.undoList.length > 0;
        }

        /**
         * Clears the history maintained, can be undone
         */
    }, {
        key: "clear",
        value: function clear() {
            this.undoList = [];
            this.redoList = [];
        }
    }]);

    return History;
})();

exports["default"] = History;
module.exports = exports["default"];